@@ -10,7 +10,7 @@ from timeflux.helpers.port import match_events
 
 
 class Epoch(Node):
-    """ Event-triggered epoching.
+    """Event-triggered epoching.
 
     This node continuously buffers a small amount of data (of a duration of ``before`` seconds) from the default input stream.
     When it detects a marker matching the ``event_trigger`` in the ``label`` column of the event input stream, it starts accumulating data for ``after`` seconds.
@@ -59,22 +59,23 @@ class Epoch(Node):
                 # Start a new epoch
                 low = index - self._before
                 high = index + self._after
-                if not self._buffer.index.is_monotonic:
-                    self.logger.warning(
-                        f"Index should be monotonic. Skipping epoch {row['data']}."
+                if self._buffer is not None:
+                    if not self._buffer.index.is_monotonic:
+                        self.logger.warning(
+                            f"Index should be monotonic. Skipping epoch {row['data']}."
+                        )
+                        return
+                    self._epochs.append(
+                        {
+                            "data": self._buffer[low:high],
+                            "meta": {
+                                "onset": index,
+                                "context": row["data"],
+                                "before": self._before.total_seconds(),
+                                "after": self._after.total_seconds(),
+                            },
+                        }
                     )
-                    return
-                self._epochs.append(
-                    {
-                        "data": self._buffer[low:high],
-                        "meta": {
-                            "onset": index,
-                            "context": row["data"],
-                            "before": self._before.total_seconds(),
-                            "after": self._after.total_seconds(),
-                        },
-                    }
-                )
 
         # Trim main buffer
         if self._buffer is not None:
@@ -107,7 +108,7 @@ class Epoch(Node):
 
 
 class ToXArray(Node):
-    """ Convert multiple epochs to DataArray
+    """Convert multiple epochs to DataArray
 
     This node iterates over input ports with valid epochs, concatenates them on the
     first axis, and creates a XArray with dimensions ('epoch', 'time', 'space') where
